#
# Copyright (c) 2006, 2007 Michael Schroeder, Novell Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program (see the file COPYING); if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
#
################################################################
#
# Build Service Configuration
#

package BSConfig;

use Net::Domain;

my $hostname = Net::Domain::hostfqdn() || 'localhost';

our $obsname = $hostname; # unique identifier for this Build Service instance
# Change also the SLP reg files in /etc/slp.reg.d/ when you touch hostname or port
our $srcserver = "http://$hostname:5352";
our $reposerver = "http://$hostname:5252";
our $serviceserver = "http://$hostname:5152";
our $servicedir = "/usr/lib/obs/service/";

#our $gpg_standard_key = "/etc/obs-default-gpg.asc";
# public download service:
our $repodownload = "http://$hostname/repositories";
# optional notification service:
#our $hermesserver = "http://$hostname/hermes";
#our $hermesnamespace = "OBS";

# For the workers only, it is possible to define multiple repository servers here.
# But only one source server is possible yet.
our @reposervers = ("http://$hostname:5252");

# proxy support:
#our $proxy = "http(s)://<user:pass>\@<host>:<port>"

# Package defaults
our $bsdir = '/srv/obs';
our $bsuser = 'obsrun';
our $bsgroup = 'obsrun';
#our $bsquotafile = '/srv/obs/quota.xml';

# To enable package downloading from backend on demand
our $enable_download_on_demand = 1;

# Package rc script / backend communication + log files
our $rundir = '/srv/obs/run';
our $logdir = '/srv/obs/log';

# optional: limit visibility of projects for some architectures
#our $limit_projects = {
# "ppc" => [ "openSUSE:Factory", "FATE" ],
# "ppc64" => [ "openSUSE:Factory", "FATE" ],
#};

# optional: allow seperation of releasnumber syncing per architecture
# one counter pool for all ppc architectures, one for i586/x86_64,
# arm archs are seperated and one for the rest in this example
our $relsync_pool = {
 "local" => "local",
 "i586" => "i586",
 "x86_64" => "i586",
 "ppc" => "ppc",
 "ppc64" => "ppc",
 "armv4l"  => "armv4l",
 "armv5el" => "armv5el",
 "armv6el" => "armv6el",
 "armv7el" => "armv7el",
 "armv8el" => "armv8el",
 "sparcv9" => "sparcv9",
 "sparc64" => "sparcv9",
};

# This is for prefer a project in scheduler, if it has high or medium
# prio events, but was not processed after $timeout minutes.
#our %max_project_timeout = (
# "openSUSE:Factory/standard" => { timeout => "30", last => "0" },
#);

# Build priority, dispatcher prefers or deprefers jobs according to this:
#our $dispatch_prio = [
# '!^home:resourcewaster',   # de-prefer jobs (take it only, when no other jobs)
# '^openSUSE:Factory',       # prefer (if there is a job for this project, take it)
#];

#No extra stage server sync
#our $stageserver = 'rsync://127.0.0.1/put-repos-main';
#our $stageserver_sync = 'rsync://127.0.0.1/trigger-repos-sync';

#No public download server
#our $repodownload = 'http://software.opensuse.org/download/repositories';

#No package signing server
#our $sign = '/usr/bin/sign';
#Extend sign call with project name as argument "--project $NAME"
#our $sign_project = 1;
#Global sign key 
#our $keyfile = '/srv/obs/openSUSE-Build-Service.asc';
#Create a key by default for new projects, if top level have not one
#our $forceprojectkeys = 1;


# Build some package only on specific hosts, or do not build on them
# our %specialbuildhost = (
# "openSUSE:Factory/glibc" => { good => [ "build20", "build21" ] },
# "openSUSE:Factory/cmake" => { bad => [ "build10", "build11" ] },
#);

# Use a special local arch for product building
# our $localarch = "x86_64";

# config options for the bs_worker
#
# run a script to check if the worker is good enough for the job
#our workerhostcheck = 'my_check_script';
# 
# Allow to build as root, exceptions per package
# the keys are actually anchored regexes
# our $norootexceptions = { "my_project/my_package" => 1, "openSUSE:Factory.*/installation-images" => 1 };

# host specific configs
my $hostconfig = "bsconfig." . Net::Domain::hostname();
if(-r $hostconfig) {
  print "reading $hostconfig...\n";
  require $hostconfig;
}

1;
